@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply arpeggiation patterns to groups of notes
 
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 
 use Moo;
 use strictures 2;
@@ -82,7 +82,7 @@ Music::MelodicDevice::Arpeggiation - Apply arpeggiation patterns to groups of no
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
@@ -156,7 +156,8 @@ Create a new C<Music::MelodicDevice::Arpeggiation> object.
   $notes = $arp->arp(\@pitches, $duration, \@pattern);
   $notes = $arp->arp(\@pitches, $duration, \@pattern, $repeats);
 
-TODO description
+Return a list of the number of notes, selected by the arpeggiated
+pattern, and distributed across the duration.
 
 =head1 SEE ALSO
 
